<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use \Zeedhi\Framework\Util\Functions;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services\PeriodoDeGeracaoRNFService;
use Teknisa\MAN\Utilities;
use \Exception as Exception;

class PeriodoDeGeracaoRNF {
    protected $periodoDeGeracaoRNFService;
    protected $utilService;
    
    public function __construct(PeriodoDeGeracaoRNFService $periodoDeGeracaoRNFService, Utilities\Util $utilService) {
        $this->periodoDeGeracaoRNFService = $periodoDeGeracaoRNFService;
        $this->utilService = $utilService;
    }
    
    public function findPeriodoGeracaoRNF(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(isset($conditions['NRORG']) && !empty($conditions['NRORG'])) {
            $result = $this->periodoDeGeracaoRNFService->findPeriodoGeracaoRNF($conditions);
            
            $response->addDataSet(new DataSet("select_periodoGeracaoRNF", $result));
        }

        return $result;
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $new = $this->periodoDeGeracaoRNFService->verificaParametrizacao($row);
            
            if(empty($new)) {
                // insert
                $this->periodoDeGeracaoRNFService->insertPeriodoGeracaoRNF($row);
                
                $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
            } else {
                // update
                $this->periodoDeGeracaoRNFService->updatePeriodoGeracaoRNF($row);
                
                $response->addNotification(new Notification("Dados atualizados com sucesso!", Notification::TYPE_SUCCESS));
            }
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}